#!/usr/bin/env python
# coding: utf-8
# 
# This program monitors the /apps/deepin/font_selector/auto_start
# gconf key, and allows the user to change it as well.

import gtk
import gtk.glade
import gconf
import os

class MyWindow:
  def __init__(self, glade_file):
    # Parse the glade file
    self.all_da_widgets = gtk.glade.XML(glade_file)

    # Get the GConf::Client, tell it we want to monitor /apps/deepin/font_selector
    self.conf_client = gconf.client_get_default()
    self.conf_client.add_dir("/apps/deepin/font_selector", gconf.CLIENT_PRELOAD_NONE)

    # Get the check_button
    self.checkbutton = self.all_da_widgets.get_widget("Auto Start")

    # Connect the check_button to a callback that can toggle it when the option
    # is changed by some outside program.
    self.conf_client.notify_add("/apps/deepin/font_selector/auto_start", self.key_changed);

    # Connect the check_button's clicked callback up so that it can change the
    # gconf setting.
    self.checkbutton.connect("clicked", self.checkbutton_toggled)

    # Determine whether button should start activated or not
    self.old_setting = self.conf_client.get_bool("/apps/deepin/font_selector/auto_start")
    self.checkbutton.set_active(self.old_setting)

    # Get the close button and connect it to hide
    close_button = self.all_da_widgets.get_widget("CloseButton")
    close_button.connect("clicked", gtk.main_quit)

    # Get the close button and connect it to hide
    main_window = self.all_da_widgets.get_widget("MainWindow")
    main_window.connect("delete_event", gtk.main_quit)
    
    dianzhen_button = self.all_da_widgets.get_widget("DianzhenButton")
    dianzhen_button.connect("clicked", self.on_DianzhenButton_clicked)
    pinghua_button = self.all_da_widgets.get_widget("PinghuaButton")
    pinghua_button.connect("clicked", self.on_PinghuaButton_clicked)
    
    #alert = self.all_da_widgets.get_widget("Alert")

  def key_changed(self, client, connection_id, entry, args):
    # Make sure the preference has a valid value
    if (entry.get_value().type == gconf.VALUE_BOOL):
      # Get the new value
      new_setting = entry.get_value().get_bool()

      # Try to handle asynchronous-ness of GConf and prevent calling
      # checkbutton_toggled again if this function was called as a
      # result of the self.conf_client.set() function call.
      if (new_setting != self.old_setting):
        self.old_setting = new_setting;
        self.checkbutton.set_active(new_setting);

  def checkbutton_toggled(self, checkbutton_widget):
    # Determine whether the checkbutton is already set or not
    is_set = self.checkbutton.get_active()
 
    # Try to handle asynchronous-ness of GConf and prevent calling
    # key_changed again if this function was called as a result of the
    # self.checkbutton.set_active() function call.
    if (is_set != self.old_setting):
      self.old_setting = is_set
      self.conf_client.set_bool("/apps/deepin/font_selector/auto_start", is_set)
      
  def on_DianzhenButton_clicked(self, widget, *args):
      self.conf_client.set_string("/apps/nautilus/preferences/desktop_font", "永中宋体 9")
      self.conf_client.set_string("/desktop/gnome/interface/document_font_name", "永中宋体 9")
      self.conf_client.set_string("/desktop/gnome/interface/font_name", "永中宋体 9")
      self.conf_client.set_string("/desktop/gnome/interface/monospace_font_name", "永中宋体 10")
      self.conf_client.set_string("/apps/metacity/general/titlebar_font", "永中宋体 Bold 9" )
      self.conf_client.set_string("/desktop/gnome/font_rendering/antialiasing", "none")

      os.system("sed -i 's/文泉驿等宽微米黑/永中宋体/g' ~/.mozilla/firefox/deepin.default/prefs.js")
      os.system("sed -i 's/文泉驿微米黑/永中宋体/g' ~/.mozilla/firefox/deepin.default/prefs.js")
      os.system("sed -i 's/文泉驿微米黑/永中宋体/g' ~/.yong/yong.ini")

  def on_PinghuaButton_clicked(self, widget, *args):
      self.conf_client.set_string("/apps/nautilus/preferences/desktop_font", "文泉驿微米黑 9")
      self.conf_client.set_string("/desktop/gnome/interface/document_font_name", "文泉驿微米黑 9")
      self.conf_client.set_string("/desktop/gnome/interface/font_name", "文泉驿微米黑 9")
      self.conf_client.set_string("/desktop/gnome/interface/monospace_font_name", "文泉驿等宽微米黑 9")
      self.conf_client.set_string("/apps/metacity/general/titlebar_font", "文泉驿微米黑 Bold 9" )
      self.conf_client.set_string("/desktop/gnome/font_rendering/antialiasing", "rgba")

      os.system("sed -i 's/\"font.name.monospace.zh-CN\", \"永中宋体\"/\"font.name.monospace.zh-CN\", \"文泉驿等宽微米黑\"/g' ~/.mozilla/firefox/deepin.default/prefs.js")
      os.system("sed -i 's/永中宋体/文泉驿微米黑/g' ~/.mozilla/firefox/deepin.default/prefs.js")
      os.system("sed -i 's/永中宋体/文泉驿微米黑/g' ~/.yong/yong.ini")

# Create the MyWindow
#window = MyWindow("fontSelector.glade")
window = MyWindow("/usr/lib/linuxdeepin/fontSelector/fontSelector.glade")

gtk.main()

